# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: biointerface.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='biointerface.proto',
  package='allego',
  syntax='proto2',
  serialized_options=b'Z\023internal/radix/grpc',
  serialized_pb=b'\n\x12\x62iointerface.proto\x12\x06\x61llego\x1a\x0c\x63ommon.proto\"!\n\x0cSpikesStdReq\x12\x11\n\tdsourceID\x18\x01 \x02(\t\"\x14\n\x12SpikesNewLoadReply\"<\n\x0fSpikesRenameReq\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x16\n\x0eisForceReplace\x18\x02 \x01(\x08\"\x13\n\x11SpikesGetIDsReply\"\xa3\x04\n\x0fSpikesSpecReply\x12\x16\n\x0e\x62iointerfaceID\x18\x01 \x02(\t\x12\x12\n\ndatasetUID\x18\x02 \x02(\t\x12\x10\n\x08\x63hecksum\x18\x03 \x02(\t\x12\x15\n\rprovenanceUID\x18\x04 \x03(\t\x12\x12\n\npersistDur\x18\x06 \x02(\x01\x12\x10\n\x08sampFreq\x18\x07 \x02(\x01\x12\x10\n\x08numSites\x18\x08 \x02(\x03\x12\x11\n\tsizeBytes\x18\t \x02(\x03\x12\x1d\n\x15\x65nabledSiteNtvChanIdx\x18\n \x03(\x05\x12\x11\n\ttimeRange\x18\x0b \x03(\x01\x12\x16\n\x0etimestampRange\x18\x0c \x03(\x03\x12\x15\n\rwallTimeStart\x18\r \x02(\t\x12$\n\x04site\x18\x0e \x03(\x0b\x32\x16.allego.SpikesSiteSpec\x12*\n\tsiteStats\x18\x11 \x01(\x0b\x32\x17.allego.SpikesSiteStats\x12\x31\n\tsensorExt\x18\x12 \x01(\x0b\x32\x1e.allego.SensorExtendedMetadata\x12(\n\x07project\x18\x13 \x01(\x0b\x32\x17.allego.ProjectMetadata\x12)\n\x07\x62ioType\x18\x14 \x02(\x0e\x32\x18.allego.BiointerfaceType\x12\x17\n\x0freqNumNeighbors\x18\x15 \x01(\x03\x12\x1c\n\x14neighborhoodRadiusUm\x18\x16 \x01(\x01\"\xc5\x04\n\x0eSpikesSiteSpec\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12,\n\x08neighbor\x18\x02 \x02(\x0b\x32\x1a.allego.NeighborDescriptor\x12\x11\n\tisEnabled\x18\x03 \x02(\x08\x12\x10\n\x08posProbe\x18\x04 \x03(\x01\x12\x11\n\tposTissue\x18\x05 \x03(\x01\x12\x11\n\tsizeBytes\x18\x06 \x02(\x03\x12\x10\n\x08sampFreq\x18\x07 \x02(\x01\x12\x15\n\rwallTimeStart\x18\x08 \x02(\t\x12\x11\n\ttimeRange\x18\t \x03(\x01\x12\x16\n\x0etimestampRange\x18\n \x03(\x03\x12\x16\n\x0espikeTimeRange\x18\x0b \x03(\x01\x12\x1b\n\x13spikeTimestampRange\x18\x0c \x03(\x03\x12\x1c\n\x14spikeTimeRangeMemory\x18\r \x03(\x01\x12!\n\x19spikeTimestampRangeMemory\x18\x0e \x03(\x03\x12\x1c\n\x14spikeCountSiteMemory\x18\x0f \x01(\x03\x12\x16\n\x0espikeCountSite\x18\x10 \x03(\x01\x12\x15\n\rspikeRateSite\x18\x11 \x03(\x01\x12\x14\n\x0cnoiseLevelSd\x18\x12 \x02(\x01\x12\x0f\n\x07snrSite\x18\x13 \x02(\x01\x12(\n\x06neuron\x18\x14 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12\x12\n\nnumNeurons\x18\x15 \x01(\x05\x12*\n\x07\x63ompLen\x18\x16 \x02(\x0b\x32\x19.allego.SpikeComponentLen\"!\n\x10SpikeLabelRecord\x12\r\n\x05label\x18\x01 \x03(\x05\"\x9a\x02\n\x0bSpikeMatrix\x12\x11\n\tnumSpikes\x18\x01 \x02(\x03\x12\x17\n\x0ftimestampsBytes\x18\x02 \x02(\x0c\x12\x0e\n\x06labels\x18\x03 \x03(\t\x12\x15\n\rwaveformBytes\x18\x04 \x01(\x0c\x12\x13\n\x0bwaveformLen\x18\x05 \x01(\x05\x12\x15\n\rfeaturesBytes\x18\x06 \x01(\x0c\x12\x13\n\x0b\x66\x65\x61turesLen\x18\x07 \x01(\x05\x12\x16\n\x0e\x66\x65\x61tures2Bytes\x18\x08 \x01(\x0c\x12\x14\n\x0c\x66\x65\x61tures2Len\x18\t \x01(\x05\x12\x13\n\x0bzscoreBytes\x18\n \x01(\x0c\x12\x11\n\tzscoreLen\x18\x0b \x01(\x05\x12\x0f\n\x07siteIdx\x18\x0c \x01(\x05\x12\x10\n\x08spikePos\x18\r \x03(\x05\"}\n\x0eSpikeMatrixSet\x12\x0b\n\x03uID\x18\x01 \x02(\t\x12\x0f\n\x07siteIdx\x18\x02 \x03(\x05\x12\x16\n\x0etimestampRange\x18\x03 \x03(\x03\x12\x10\n\x08sampFreq\x18\x04 \x02(\x01\x12#\n\x06spkMtx\x18\x05 \x03(\x0b\x32\x13.allego.SpikeMatrix\"\x93\x01\n\x14NeuronSpikeMatrixSet\x12\x0e\n\x06labels\x18\x01 \x03(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x0f\n\x07siteIdx\x18\x03 \x03(\x05\x12#\n\x06spkMtx\x18\x04 \x03(\x0b\x32\x13.allego.SpikeMatrix\x12\x16\n\x0etimestampRange\x18\x05 \x03(\x03\x12\x0b\n\x03uID\x18\x06 \x02(\t\"\xa7\x02\n\x1c\x42iointerfaceGetSpikesRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\'\n\x04mode\x18\x02 \x02(\x0e\x32\x19.allego.NeuronsSignalMode\x12\x12\n\nntvChanIdx\x18\x03 \x03(\x05\x12\x11\n\ttimeStart\x18\x04 \x02(\x01\x12\x10\n\x08timeStop\x18\x05 \x02(\x01\x12-\n\x0bspikeLabels\x18\x06 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\x12\x1b\n\x13maxSpikesPerChannel\x18\x07 \x02(\x05\x12\x33\n\tspikeComp\x18\x08 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\x12\x11\n\tspkSortID\x18\t \x01(\t\"\x99\x01\n\x1a\x42iointerfaceGetHistRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12%\n\x04mode\x18\x02 \x02(\x0e\x32\x17.allego.HistScalingMode\x12\x12\n\nntvChanIdx\x18\x03 \x03(\x05\x12-\n\x0bspikeLabels\x18\x04 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\"\x90\x01\n%BiointerfaceGetSpikeTimestampsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12-\n\x0bspikeLabels\x18\x06 \x03(\x0b\x32\x18.allego.SpikeLabelRecord\"\x8b\x01\n BiointerfaceSpikeTimestampsReply\x12<\n\x18spikeTimestampsByChannel\x18\x02 \x03(\x0b\x32\x1a.allego.SpikeTimestampData\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimeStampRange\x18\x04 \x03(\x03\"S\n)BiointerfaceSeekEndSpikeTimestampsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x13\n\x0b\x63omponentID\x18\x02 \x02(\t\"Y\n\x1d\x42iointerfaceGetNeuronsRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\"\xe4\x02\n\x1b\x42iointerfaceGetNeuronsReply\x12;\n\x04site\x18\x01 \x03(\x0b\x32-.allego.BiointerfaceGetNeuronsReply.SiteEntry\x1a\x36\n\x0eSpikeRateChunk\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x11\n\tspikeRate\x18\x02 \x03(\x01\x1av\n\x07NeuronL\x12(\n\x06neuron\x18\x01 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12\x41\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x32.allego.BiointerfaceGetNeuronsReply.SpikeRateChunk\x1aX\n\tSiteEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12:\n\x05value\x18\x02 \x01(\x0b\x32+.allego.BiointerfaceGetNeuronsReply.NeuronL:\x02\x38\x01\"\x87\x02\n\x0fSpikesSiteStats\x12\x17\n\x0fspikeCountStats\x18\t \x03(\x01\x12\x1e\n\x16labeledSpikeCountStats\x18\n \x03(\x01\x12 \n\x18unlabeledSpikeCountStats\x18\x0b \x03(\x01\x12\x16\n\x0espikeRateStats\x18\x0c \x03(\x01\x12\x1d\n\x15labeledSpikeRateStats\x18\r \x03(\x01\x12\x1f\n\x17unlabeledSpikeRateStats\x18\x0e \x03(\x01\x12\x16\n\x0esiteNoiseStats\x18\x0f \x03(\x01\x12\x14\n\x0csiteSnrStats\x18\x10 \x03(\x01\x12\x13\n\x0bneuronStats\x18\x11 \x03(\x01\"f\n\x11SpikeComponentLen\x12\x10\n\x08waveform\x18\x01 \x02(\x05\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x02(\x05\x12\x10\n\x08\x66\x65\x61ture2\x18\x03 \x02(\x05\x12\x0e\n\x06zscore\x18\x04 \x02(\x05\x12\x0c\n\x04nbrs\x18\x05 \x03(\x05\"\xa8\x01\n\x12NeighborDescriptor\x12\x0e\n\x06radius\x18\x01 \x02(\x01\x12\x12\n\nntvChanIdx\x18\x02 \x03(\x05\x12\x10\n\x08\x64istance\x18\x03 \x03(\x01\x12\x10\n\x08thetaDeg\x18\x04 \x03(\x01\x12\x0e\n\x06phiDeg\x18\x05 \x03(\x01\x12\x0b\n\x03num\x18\x06 \x02(\x05\x12\x14\n\x0cSiteCenterUm\x18\x07 \x03(\x01\x12\x17\n\x0fSiteCenterTcsUm\x18\x08 \x03(\x01\"\xf3\x01\n\x10NeuronDescriptor\x12\x10\n\x08neuronID\x18\x01 \x02(\t\x12\x16\n\x0esiteNtvChanIdx\x18\x02 \x02(\x05\x12\x12\n\nspikeLabel\x18\x03 \x02(\t\x12\x10\n\x08posProbe\x18\x04 \x03(\x01\x12\x11\n\tposTissue\x18\x05 \x03(\x01\x12\x12\n\nspikeCount\x18\x06 \x02(\x03\x12\x11\n\tspikeRate\x18\x07 \x02(\x01\x12\x16\n\x0emeanAbsPeakWfm\x18\x08 \x01(\x01\x12\x0b\n\x03snr\x18\t \x01(\x01\x12\x30\n\x08metaData\x18\n \x01(\x0b\x32\x1e.allego.NeuronExtendedMetadata\"\x86\x01\n\x16NeuronExtendedMetadata\x12\x18\n\x10neuronCatalogUID\x18\x01 \x01(\t\x12\x13\n\x0b\x65nsembleUID\x18\x02 \x01(\t\x12\x17\n\x0f\x66uncAssemblyUID\x18\x03 \x03(\t\x12\x12\n\ndatasetUID\x18\x04 \x01(\t\x12\x10\n\x08probeUID\x18\x05 \x01(\t\"\x8b\x01\n\x10NeuronStatistics\x12\x1a\n\x12WaveformAvgAbsAmpl\x18\x01 \x02(\x01\x12\x0b\n\x03Snr\x18\x02 \x02(\x01\x12\x12\n\nspikeCount\x18\x03 \x02(\x03\x12\x14\n\x0c\x61vgSpikeRate\x18\x04 \x02(\x01\x12$\n\x04isih\x18\x05 \x01(\x0b\x32\x16.allego.NeuronHistData\"|\n\x0fSpikeDescriptor\x12\x11\n\ttimestamp\x18\x01 \x02(\x03\x12\r\n\x05label\x18\x02 \x02(\t\x12\x10\n\x08waveform\x18\x03 \x03(\x02\x12\x10\n\x08\x66\x65\x61tures\x18\x04 \x03(\x02\x12\x13\n\x0b\x64\x65\x63\x46\x65\x61tures\x18\x05 \x03(\x01\x12\x0e\n\x06zscore\x18\x06 \x03(\x02\"g\n\tSpikeData\x12&\n\x05spike\x18\x01 \x03(\x0b\x32\x17.allego.SpikeDescriptor\x12\x18\n\x10waveformMaxValue\x18\x02 \x02(\x02\x12\x18\n\x10waveformMinValue\x18\x03 \x02(\x02\"1\n\rSpikeTimeData\x12\x11\n\tspikeTime\x18\x01 \x03(\x01\x12\r\n\x05label\x18\x02 \x03(\x05\"Q\n\x12SpikeTimestampData\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x17\n\x0fspikeTimestamps\x18\x02 \x03(\x03\x12\x0e\n\x06labels\x18\x03 \x03(\x05\"\xb6\x02\n\x17SpikeTemplateDescriptor\x12\x10\n\x08neuronID\x18\x01 \x02(\t\x12\r\n\x05label\x18\x02 \x02(\t\x12\x11\n\tnumSpikes\x18\x03 \x02(\x03\x12\x10\n\x08waveform\x18\x04 \x02(\x0c\x12\x12\n\nwaveformSd\x18\x05 \x02(\x0c\x12\x13\n\x0blenWaveform\x18\x06 \x02(\x03\x12\x10\n\x08\x66\x65\x61tures\x18\x07 \x02(\x0c\x12\x12\n\nfeaturesSd\x18\x08 \x02(\x0c\x12\x13\n\x0blenFeatures\x18\t \x02(\x03\x12\x11\n\tfeatures2\x18\n \x02(\x0c\x12\x13\n\x0b\x66\x65\x61tures2Sd\x18\x0b \x02(\x0c\x12\x14\n\x0clenFeatures2\x18\x0c \x02(\x03\x12\x0e\n\x06zscore\x18\r \x02(\x0c\x12\x10\n\x08zscoreSd\x18\x0e \x02(\x0c\x12\x11\n\tlenZscore\x18\x0f \x02(\x03\"[\n\x12SiteSpikeTemplates\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x31\n\x08template\x18\x02 \x03(\x0b\x32\x1f.allego.SpikeTemplateDescriptor\"\x97\x01\n\x1f\x42iointerfaceSpikeTemplatesReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12(\n\x04site\x18\x05 \x03(\x0b\x32\x1a.allego.SiteSpikeTemplates\"@\n\x14\x42iointerfaceMetaData\x12(\n\x0bsignalGroup\x18\x01 \x01(\x0b\x32\x13.allego.SignalGroup\"\xd6\x01\n\x1a\x42iointerfaceSpikeDataReply\x12\x16\n\x0e\x62iointerfaceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x16\n\x0etimestampRange\x18\x04 \x03(\x03\x12\x12\n\nntvChanIdx\x18\x05 \x03(\x05\x12\x1f\n\x04site\x18\x06 \x03(\x0b\x32\x11.allego.SpikeData\x12.\n\x08metaData\x18\x07 \x01(\x0b\x32\x1c.allego.BiointerfaceMetaData\"y\n\x1fSpikeDataDenseChannelDescriptor\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\x0e\n\x06labels\x18\x02 \x03(\x05\x12\x18\n\x10waveformMaxValue\x18\x03 \x02(\x02\x12\x18\n\x10waveformMinValue\x18\x04 \x02(\x02\"\xb6\x01\n\x1f\x42iointerfaceSpikeDataDenseReply\x12\x11\n\ttimeRange\x18\x01 \x03(\x01\x12\x17\n\x0fwaveformNPoints\x18\x02 \x02(\x05\x12\x14\n\x0ctotalNSpikes\x18\x03 \x02(\x05\x12\x43\n\x12\x63hannelDescriptors\x18\x04 \x03(\x0b\x32\'.allego.SpikeDataDenseChannelDescriptor\x12\x0c\n\x04\x64\x61ta\x18\x05 \x02(\x0c\"\x8a\x01\n\x17GroupSpikeTimeDataReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12#\n\x04site\x18\x05 \x03(\x0b\x32\x15.allego.SpikeTimeData\"v\n\x16\x42iointerfaceSpiketrain\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x11\n\ttimeRange\x18\x02 \x03(\x01\x12\x10\n\x08sampFreq\x18\x03 \x02(\x01\x12$\n\x04site\x18\x04 \x03(\x0b\x32\x16.allego.SiteSpiketrain\"p\n\x0eSiteSpiketrain\x12\x12\n\nntvChanIdx\x18\x01 \x02(\x05\x12\"\n\x06neuron\x18\x02 \x03(\x0b\x32\x12.allego.Spiketrain\x12\x10\n\x08sampFreq\x18\x03 \x02(\x01\x12\x14\n\x0cnumNeighbors\x18\x04 \x02(\x05\"\x8b\x02\n\nSpiketrain\x12\x10\n\x08sampFreq\x18\x01 \x02(\x01\x12\r\n\x05label\x18\x02 \x02(\x05\x12\x17\n\x0fspikeTimestamps\x18\x03 \x03(\x03\x12\x14\n\x0cwaveformData\x18\x05 \x03(\x02\x12\x15\n\rwaveformShape\x18\x06 \x03(\x05\x12\x13\n\x0b\x66\x65\x61tureData\x18\x07 \x03(\x02\x12\x14\n\x0c\x66\x65\x61tureShape\x18\x08 \x03(\x05\x12\x12\n\nzscoreData\x18\t \x03(\x02\x12\x13\n\x0bzscoreShape\x18\n \x03(\x05\x12,\n\nneuronDesc\x18\x0f \x02(\x0b\x32\x18.allego.NeuronDescriptor\x12\x14\n\x0cnumNeighbors\x18\x11 \x02(\x05\"\xb6\x01\n\x0eNeuronHistData\x12\x13\n\x0b\x62inWidthSec\x18\x01 \x02(\x01\x12\x15\n\rhistTimeRange\x18\x02 \x03(\x01\x12%\n\x04mode\x18\x03 \x02(\x0e\x32\x17.allego.HistScalingMode\x12\x14\n\x0cnumRefEvents\x18\x04 \x02(\x03\x12\x11\n\tnumSpikes\x18\x05 \x02(\x03\x12\x1a\n\x12numProcessedSpikes\x18\x06 \x02(\x03\x12\x0c\n\x04hist\x18\x07 \x03(\x01\"\x9d\x01\n\x0cSiteHistData\x12\x14\n\x0csitePosProbe\x18\x01 \x03(\x01\x12\x14\n\x0csitePosBrain\x18\x02 \x03(\x01\x12(\n\x06neuron\x18\x03 \x03(\x0b\x32\x18.allego.NeuronDescriptor\x12$\n\x04hist\x18\x04 \x03(\x0b\x32\x16.allego.NeuronHistData\x12\x11\n\ttimeRange\x18\x05 \x03(\x01\"\x8b\x01\n\x19\x42iointerfaceHistDataReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x10\n\x08sampFreq\x18\x02 \x02(\x01\x12\x11\n\ttimeRange\x18\x03 \x03(\x01\x12\x12\n\nntvChanIdx\x18\x04 \x03(\x05\x12\"\n\x04site\x18\x05 \x03(\x0b\x32\x14.allego.SiteHistData\"\xb4\x01\n\x17\x42iointerfaceSaveRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x11\n\ttimeRange\x18\x04 \x03(\x01\x12\x33\n\tspikeComp\x18\x05 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\x12\x1e\n\x16includeNeuronTemplates\x18\x06 \x02(\x08\"\xac\x01\n\x17\x42iointerfaceLoadRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x13\n\x0buidFragment\x18\x04 \x02(\t\x12\x33\n\tspikeComp\x18\x05 \x03(\x0e\x32 .allego.SpikeDescriptorComponent\x12\x14\n\x0c\x66orceReplace\x18\x06 \x02(\x08\"\x95\x01\n\x19\x42iointerfaceSaveLoadReply\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x0c\n\x04path\x18\x02 \x02(\t\x12\x10\n\x08\x62\x61seName\x18\x03 \x02(\t\x12\x0b\n\x03uid\x18\x04 \x02(\t\x12\x1c\n\x14\x62iointerfaceMetaFile\x18\x05 \x02(\t\x12\x1a\n\x12neuronTemplateFile\x18\x06 \x02(\t\"2\n\x17\x42iointerfaceGetIDsReply\x12\x17\n\x0f\x62iointerfaceIDs\x18\x01 \x03(\t\"\xef\x01\n\x16\x42iointerfaceVizRequest\x12\x11\n\tdsourceID\x18\x01 \x02(\t\x12\x35\n\x07vizType\x18\x02 \x02(\x0e\x32$.allego.BiointerfaceVizRequest.VType\x12\x12\n\nnumSamples\x18\x03 \x02(\x05\x12\x14\n\x0cisYAutoScale\x18\x04 \x02(\x08\x12\x0c\n\x04yLim\x18\x05 \x03(\x01\x12\x0e\n\x06\x66igDir\x18\x06 \x01(\t\x12\x12\n\nisAutoOpen\x18\x07 \x01(\x08\"/\n\x05VType\x12\x15\n\x11VIZ_BIO_TEMPLATES\x10\x00\x12\x0f\n\x0bVIZ_BIO_DEV\x10\x01\"2\n\x14\x42iointerfaceVizReply\x12\x1a\n\x12pngPathAndFileName\x18\x01 \x01(\t*T\n\x10\x42iointerfaceType\x12\x13\n\x0f\x42IO_SPIKETRAINS\x10\x00\x12\x14\n\x10\x42IO_SPIKES_CACHE\x10\x01\x12\x15\n\x11\x42IO_SPIKES_STREAM\x10\x02* \n\x12SpikesImportSchema\x12\n\n\x06NI_SIM\x10\x00*@\n\x13\x42iointerfaceCommand\x12\x13\n\x0f\x42IO_CMD_SAVE_ON\x10\x00\x12\x14\n\x10\x42IO_CMD_SAVE_OFF\x10\x01*J\n\x11\x42iointerfaceState\x12\x0f\n\x0b\x42IO_SAVE_ON\x10\x00\x12\x10\n\x0c\x42IO_SAVE_OFF\x10\x01\x12\x12\n\x0e\x42IO_CONFIGURED\x10\x02*X\n\x11NeuronsSignalMode\x12\n\n\x06Spikes\x10\x00\x12\x13\n\x0fSpikeTimestamps\x10\x01\x12\x0e\n\nSpikeTimes\x10\x02\x12\x12\n\x0eSpikeWaveforms\x10\x03*q\n\x18SpikeDescriptorComponent\x12\x0e\n\nCTimestamp\x10\x00\x12\n\n\x06\x43Label\x10\x01\x12\r\n\tCWaveform\x10\x02\x12\x0c\n\x08\x43\x46\x65\x61ture\x10\x03\x12\x0f\n\x0b\x43\x44\x65\x63\x46\x65\x61ture\x10\x04\x12\x0b\n\x07\x43Zscore\x10\x05*S\n\x0fHistScalingMode\x12\x0c\n\x08\x41sSpikes\x10\x00\x12\x0f\n\x0b\x41sSpikeRate\x10\x01\x12\n\n\x06\x41sNorm\x10\x02\x12\n\n\x06\x41sProb\x10\x03\x12\t\n\x05\x41sRaw\x10\x04\x42\x15Z\x13internal/radix/grpc'
  ,
  dependencies=[common__pb2.DESCRIPTOR,])

_BIOINTERFACETYPE = _descriptor.EnumDescriptor(
  name='BiointerfaceType',
  full_name='allego.BiointerfaceType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIO_SPIKETRAINS', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_SPIKES_CACHE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_SPIKES_STREAM', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7763,
  serialized_end=7847,
)
_sym_db.RegisterEnumDescriptor(_BIOINTERFACETYPE)

BiointerfaceType = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACETYPE)
_SPIKESIMPORTSCHEMA = _descriptor.EnumDescriptor(
  name='SpikesImportSchema',
  full_name='allego.SpikesImportSchema',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NI_SIM', index=0, number=0,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7849,
  serialized_end=7881,
)
_sym_db.RegisterEnumDescriptor(_SPIKESIMPORTSCHEMA)

SpikesImportSchema = enum_type_wrapper.EnumTypeWrapper(_SPIKESIMPORTSCHEMA)
_BIOINTERFACECOMMAND = _descriptor.EnumDescriptor(
  name='BiointerfaceCommand',
  full_name='allego.BiointerfaceCommand',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIO_CMD_SAVE_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_CMD_SAVE_OFF', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7883,
  serialized_end=7947,
)
_sym_db.RegisterEnumDescriptor(_BIOINTERFACECOMMAND)

BiointerfaceCommand = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACECOMMAND)
_BIOINTERFACESTATE = _descriptor.EnumDescriptor(
  name='BiointerfaceState',
  full_name='allego.BiointerfaceState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BIO_SAVE_ON', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_SAVE_OFF', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BIO_CONFIGURED', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7949,
  serialized_end=8023,
)
_sym_db.RegisterEnumDescriptor(_BIOINTERFACESTATE)

BiointerfaceState = enum_type_wrapper.EnumTypeWrapper(_BIOINTERFACESTATE)
_NEURONSSIGNALMODE = _descriptor.EnumDescriptor(
  name='NeuronsSignalMode',
  full_name='allego.NeuronsSignalMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Spikes', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpikeTimestamps', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpikeTimes', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SpikeWaveforms', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8025,
  serialized_end=8113,
)
_sym_db.RegisterEnumDescriptor(_NEURONSSIGNALMODE)

NeuronsSignalMode = enum_type_wrapper.EnumTypeWrapper(_NEURONSSIGNALMODE)
_SPIKEDESCRIPTORCOMPONENT = _descriptor.EnumDescriptor(
  name='SpikeDescriptorComponent',
  full_name='allego.SpikeDescriptorComponent',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CTimestamp', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLabel', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CWaveform', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CFeature', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CDecFeature', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CZscore', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8115,
  serialized_end=8228,
)
_sym_db.RegisterEnumDescriptor(_SPIKEDESCRIPTORCOMPONENT)

SpikeDescriptorComponent = enum_type_wrapper.EnumTypeWrapper(_SPIKEDESCRIPTORCOMPONENT)
_HISTSCALINGMODE = _descriptor.EnumDescriptor(
  name='HistScalingMode',
  full_name='allego.HistScalingMode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AsSpikes', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AsSpikeRate', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AsNorm', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AsProb', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AsRaw', index=4, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8230,
  serialized_end=8313,
)
_sym_db.RegisterEnumDescriptor(_HISTSCALINGMODE)

HistScalingMode = enum_type_wrapper.EnumTypeWrapper(_HISTSCALINGMODE)
BIO_SPIKETRAINS = 0
BIO_SPIKES_CACHE = 1
BIO_SPIKES_STREAM = 2
NI_SIM = 0
BIO_CMD_SAVE_ON = 0
BIO_CMD_SAVE_OFF = 1
BIO_SAVE_ON = 0
BIO_SAVE_OFF = 1
BIO_CONFIGURED = 2
Spikes = 0
SpikeTimestamps = 1
SpikeTimes = 2
SpikeWaveforms = 3
CTimestamp = 0
CLabel = 1
CWaveform = 2
CFeature = 3
CDecFeature = 4
CZscore = 5
AsSpikes = 0
AsSpikeRate = 1
AsNorm = 2
AsProb = 3
AsRaw = 4


_BIOINTERFACEVIZREQUEST_VTYPE = _descriptor.EnumDescriptor(
  name='VType',
  full_name='allego.BiointerfaceVizRequest.VType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VIZ_BIO_TEMPLATES', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VIZ_BIO_DEV', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7662,
  serialized_end=7709,
)
_sym_db.RegisterEnumDescriptor(_BIOINTERFACEVIZREQUEST_VTYPE)


_SPIKESSTDREQ = _descriptor.Descriptor(
  name='SpikesStdReq',
  full_name='allego.SpikesStdReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.SpikesStdReq.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=77,
)


_SPIKESNEWLOADREPLY = _descriptor.Descriptor(
  name='SpikesNewLoadReply',
  full_name='allego.SpikesNewLoadReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=99,
)


_SPIKESRENAMEREQ = _descriptor.Descriptor(
  name='SpikesRenameReq',
  full_name='allego.SpikesRenameReq',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.SpikesRenameReq.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isForceReplace', full_name='allego.SpikesRenameReq.isForceReplace', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=161,
)


_SPIKESGETIDSREPLY = _descriptor.Descriptor(
  name='SpikesGetIDsReply',
  full_name='allego.SpikesGetIDsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=182,
)


_SPIKESSPECREPLY = _descriptor.Descriptor(
  name='SpikesSpecReply',
  full_name='allego.SpikesSpecReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='biointerfaceID', full_name='allego.SpikesSpecReply.biointerfaceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetUID', full_name='allego.SpikesSpecReply.datasetUID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checksum', full_name='allego.SpikesSpecReply.checksum', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provenanceUID', full_name='allego.SpikesSpecReply.provenanceUID', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persistDur', full_name='allego.SpikesSpecReply.persistDur', index=4,
      number=6, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SpikesSpecReply.sampFreq', index=5,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSites', full_name='allego.SpikesSpecReply.numSites', index=6,
      number=8, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='allego.SpikesSpecReply.sizeBytes', index=7,
      number=9, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabledSiteNtvChanIdx', full_name='allego.SpikesSpecReply.enabledSiteNtvChanIdx', index=8,
      number=10, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikesSpecReply.timeRange', index=9,
      number=11, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.SpikesSpecReply.timestampRange', index=10,
      number=12, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wallTimeStart', full_name='allego.SpikesSpecReply.wallTimeStart', index=11,
      number=13, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.SpikesSpecReply.site', index=12,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteStats', full_name='allego.SpikesSpecReply.siteStats', index=13,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensorExt', full_name='allego.SpikesSpecReply.sensorExt', index=14,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='project', full_name='allego.SpikesSpecReply.project', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bioType', full_name='allego.SpikesSpecReply.bioType', index=16,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reqNumNeighbors', full_name='allego.SpikesSpecReply.reqNumNeighbors', index=17,
      number=21, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neighborhoodRadiusUm', full_name='allego.SpikesSpecReply.neighborhoodRadiusUm', index=18,
      number=22, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=185,
  serialized_end=732,
)


_SPIKESSITESPEC = _descriptor.Descriptor(
  name='SpikesSiteSpec',
  full_name='allego.SpikesSiteSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikesSiteSpec.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neighbor', full_name='allego.SpikesSiteSpec.neighbor', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isEnabled', full_name='allego.SpikesSiteSpec.isEnabled', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbe', full_name='allego.SpikesSiteSpec.posProbe', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posTissue', full_name='allego.SpikesSiteSpec.posTissue', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeBytes', full_name='allego.SpikesSiteSpec.sizeBytes', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SpikesSiteSpec.sampFreq', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='wallTimeStart', full_name='allego.SpikesSiteSpec.wallTimeStart', index=7,
      number=8, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SpikesSiteSpec.timeRange', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.SpikesSiteSpec.timestampRange', index=9,
      number=10, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimeRange', full_name='allego.SpikesSiteSpec.spikeTimeRange', index=10,
      number=11, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimestampRange', full_name='allego.SpikesSiteSpec.spikeTimestampRange', index=11,
      number=12, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimeRangeMemory', full_name='allego.SpikesSiteSpec.spikeTimeRangeMemory', index=12,
      number=13, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimestampRangeMemory', full_name='allego.SpikesSiteSpec.spikeTimestampRangeMemory', index=13,
      number=14, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeCountSiteMemory', full_name='allego.SpikesSiteSpec.spikeCountSiteMemory', index=14,
      number=15, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeCountSite', full_name='allego.SpikesSiteSpec.spikeCountSite', index=15,
      number=16, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRateSite', full_name='allego.SpikesSiteSpec.spikeRateSite', index=16,
      number=17, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='noiseLevelSd', full_name='allego.SpikesSiteSpec.noiseLevelSd', index=17,
      number=18, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snrSite', full_name='allego.SpikesSiteSpec.snrSite', index=18,
      number=19, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuron', full_name='allego.SpikesSiteSpec.neuron', index=19,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeurons', full_name='allego.SpikesSiteSpec.numNeurons', index=20,
      number=21, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compLen', full_name='allego.SpikesSiteSpec.compLen', index=21,
      number=22, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=1316,
)


_SPIKELABELRECORD = _descriptor.Descriptor(
  name='SpikeLabelRecord',
  full_name='allego.SpikeLabelRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.SpikeLabelRecord.label', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1318,
  serialized_end=1351,
)


_SPIKEMATRIX = _descriptor.Descriptor(
  name='SpikeMatrix',
  full_name='allego.SpikeMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.SpikeMatrix.numSpikes', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampsBytes', full_name='allego.SpikeMatrix.timestampsBytes', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='allego.SpikeMatrix.labels', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformBytes', full_name='allego.SpikeMatrix.waveformBytes', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformLen', full_name='allego.SpikeMatrix.waveformLen', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featuresBytes', full_name='allego.SpikeMatrix.featuresBytes', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featuresLen', full_name='allego.SpikeMatrix.featuresLen', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features2Bytes', full_name='allego.SpikeMatrix.features2Bytes', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features2Len', full_name='allego.SpikeMatrix.features2Len', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscoreBytes', full_name='allego.SpikeMatrix.zscoreBytes', index=9,
      number=10, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscoreLen', full_name='allego.SpikeMatrix.zscoreLen', index=10,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteIdx', full_name='allego.SpikeMatrix.siteIdx', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikePos', full_name='allego.SpikeMatrix.spikePos', index=12,
      number=13, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1636,
)


_SPIKEMATRIXSET = _descriptor.Descriptor(
  name='SpikeMatrixSet',
  full_name='allego.SpikeMatrixSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.SpikeMatrixSet.uID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteIdx', full_name='allego.SpikeMatrixSet.siteIdx', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.SpikeMatrixSet.timestampRange', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SpikeMatrixSet.sampFreq', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spkMtx', full_name='allego.SpikeMatrixSet.spkMtx', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1638,
  serialized_end=1763,
)


_NEURONSPIKEMATRIXSET = _descriptor.Descriptor(
  name='NeuronSpikeMatrixSet',
  full_name='allego.NeuronSpikeMatrixSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='labels', full_name='allego.NeuronSpikeMatrixSet.labels', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.NeuronSpikeMatrixSet.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteIdx', full_name='allego.NeuronSpikeMatrixSet.siteIdx', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spkMtx', full_name='allego.NeuronSpikeMatrixSet.spkMtx', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.NeuronSpikeMatrixSet.timestampRange', index=4,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uID', full_name='allego.NeuronSpikeMatrixSet.uID', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1766,
  serialized_end=1913,
)


_BIOINTERFACEGETSPIKESREQUEST = _descriptor.Descriptor(
  name='BiointerfaceGetSpikesRequest',
  full_name='allego.BiointerfaceGetSpikesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceGetSpikesRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.BiointerfaceGetSpikesRequest.mode', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceGetSpikesRequest.ntvChanIdx', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStart', full_name='allego.BiointerfaceGetSpikesRequest.timeStart', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStop', full_name='allego.BiointerfaceGetSpikesRequest.timeStop', index=4,
      number=5, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabels', full_name='allego.BiointerfaceGetSpikesRequest.spikeLabels', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='maxSpikesPerChannel', full_name='allego.BiointerfaceGetSpikesRequest.maxSpikesPerChannel', index=6,
      number=7, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeComp', full_name='allego.BiointerfaceGetSpikesRequest.spikeComp', index=7,
      number=8, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spkSortID', full_name='allego.BiointerfaceGetSpikesRequest.spkSortID', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1916,
  serialized_end=2211,
)


_BIOINTERFACEGETHISTREQUEST = _descriptor.Descriptor(
  name='BiointerfaceGetHistRequest',
  full_name='allego.BiointerfaceGetHistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceGetHistRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.BiointerfaceGetHistRequest.mode', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceGetHistRequest.ntvChanIdx', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabels', full_name='allego.BiointerfaceGetHistRequest.spikeLabels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2214,
  serialized_end=2367,
)


_BIOINTERFACEGETSPIKETIMESTAMPSREQUEST = _descriptor.Descriptor(
  name='BiointerfaceGetSpikeTimestampsRequest',
  full_name='allego.BiointerfaceGetSpikeTimestampsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceGetSpikeTimestampsRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceGetSpikeTimestampsRequest.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceGetSpikeTimestampsRequest.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabels', full_name='allego.BiointerfaceGetSpikeTimestampsRequest.spikeLabels', index=3,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2370,
  serialized_end=2514,
)


_BIOINTERFACESPIKETIMESTAMPSREPLY = _descriptor.Descriptor(
  name='BiointerfaceSpikeTimestampsReply',
  full_name='allego.BiointerfaceSpikeTimestampsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeTimestampsByChannel', full_name='allego.BiointerfaceSpikeTimestampsReply.spikeTimestampsByChannel', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSpikeTimestampsReply.timeRange', index=1,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeStampRange', full_name='allego.BiointerfaceSpikeTimestampsReply.timeStampRange', index=2,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2517,
  serialized_end=2656,
)


_BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST = _descriptor.Descriptor(
  name='BiointerfaceSeekEndSpikeTimestampsRequest',
  full_name='allego.BiointerfaceSeekEndSpikeTimestampsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceSeekEndSpikeTimestampsRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='componentID', full_name='allego.BiointerfaceSeekEndSpikeTimestampsRequest.componentID', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2658,
  serialized_end=2741,
)


_BIOINTERFACEGETNEURONSREQUEST = _descriptor.Descriptor(
  name='BiointerfaceGetNeuronsRequest',
  full_name='allego.BiointerfaceGetNeuronsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceGetNeuronsRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceGetNeuronsRequest.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceGetNeuronsRequest.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2743,
  serialized_end=2832,
)


_BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK = _descriptor.Descriptor(
  name='SpikeRateChunk',
  full_name='allego.BiointerfaceGetNeuronsReply.SpikeRateChunk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceGetNeuronsReply.SpikeRateChunk.timeRange', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRate', full_name='allego.BiointerfaceGetNeuronsReply.SpikeRateChunk.spikeRate', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2927,
  serialized_end=2981,
)

_BIOINTERFACEGETNEURONSREPLY_NEURONL = _descriptor.Descriptor(
  name='NeuronL',
  full_name='allego.BiointerfaceGetNeuronsReply.NeuronL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='neuron', full_name='allego.BiointerfaceGetNeuronsReply.NeuronL.neuron', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='allego.BiointerfaceGetNeuronsReply.NeuronL.chunk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2983,
  serialized_end=3101,
)

_BIOINTERFACEGETNEURONSREPLY_SITEENTRY = _descriptor.Descriptor(
  name='SiteEntry',
  full_name='allego.BiointerfaceGetNeuronsReply.SiteEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='allego.BiointerfaceGetNeuronsReply.SiteEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='allego.BiointerfaceGetNeuronsReply.SiteEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3103,
  serialized_end=3191,
)

_BIOINTERFACEGETNEURONSREPLY = _descriptor.Descriptor(
  name='BiointerfaceGetNeuronsReply',
  full_name='allego.BiointerfaceGetNeuronsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.BiointerfaceGetNeuronsReply.site', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK, _BIOINTERFACEGETNEURONSREPLY_NEURONL, _BIOINTERFACEGETNEURONSREPLY_SITEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2835,
  serialized_end=3191,
)


_SPIKESSITESTATS = _descriptor.Descriptor(
  name='SpikesSiteStats',
  full_name='allego.SpikesSiteStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeCountStats', full_name='allego.SpikesSiteStats.spikeCountStats', index=0,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labeledSpikeCountStats', full_name='allego.SpikesSiteStats.labeledSpikeCountStats', index=1,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlabeledSpikeCountStats', full_name='allego.SpikesSiteStats.unlabeledSpikeCountStats', index=2,
      number=11, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRateStats', full_name='allego.SpikesSiteStats.spikeRateStats', index=3,
      number=12, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labeledSpikeRateStats', full_name='allego.SpikesSiteStats.labeledSpikeRateStats', index=4,
      number=13, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unlabeledSpikeRateStats', full_name='allego.SpikesSiteStats.unlabeledSpikeRateStats', index=5,
      number=14, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNoiseStats', full_name='allego.SpikesSiteStats.siteNoiseStats', index=6,
      number=15, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteSnrStats', full_name='allego.SpikesSiteStats.siteSnrStats', index=7,
      number=16, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronStats', full_name='allego.SpikesSiteStats.neuronStats', index=8,
      number=17, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3194,
  serialized_end=3457,
)


_SPIKECOMPONENTLEN = _descriptor.Descriptor(
  name='SpikeComponentLen',
  full_name='allego.SpikeComponentLen',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='waveform', full_name='allego.SpikeComponentLen.waveform', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature', full_name='allego.SpikeComponentLen.feature', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feature2', full_name='allego.SpikeComponentLen.feature2', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscore', full_name='allego.SpikeComponentLen.zscore', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nbrs', full_name='allego.SpikeComponentLen.nbrs', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3459,
  serialized_end=3561,
)


_NEIGHBORDESCRIPTOR = _descriptor.Descriptor(
  name='NeighborDescriptor',
  full_name='allego.NeighborDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='radius', full_name='allego.NeighborDescriptor.radius', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.NeighborDescriptor.ntvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='distance', full_name='allego.NeighborDescriptor.distance', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='thetaDeg', full_name='allego.NeighborDescriptor.thetaDeg', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='phiDeg', full_name='allego.NeighborDescriptor.phiDeg', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num', full_name='allego.NeighborDescriptor.num', index=5,
      number=6, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SiteCenterUm', full_name='allego.NeighborDescriptor.SiteCenterUm', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SiteCenterTcsUm', full_name='allego.NeighborDescriptor.SiteCenterTcsUm', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3564,
  serialized_end=3732,
)


_NEURONDESCRIPTOR = _descriptor.Descriptor(
  name='NeuronDescriptor',
  full_name='allego.NeuronDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='neuronID', full_name='allego.NeuronDescriptor.neuronID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='siteNtvChanIdx', full_name='allego.NeuronDescriptor.siteNtvChanIdx', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeLabel', full_name='allego.NeuronDescriptor.spikeLabel', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posProbe', full_name='allego.NeuronDescriptor.posProbe', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='posTissue', full_name='allego.NeuronDescriptor.posTissue', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeCount', full_name='allego.NeuronDescriptor.spikeCount', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeRate', full_name='allego.NeuronDescriptor.spikeRate', index=6,
      number=7, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='meanAbsPeakWfm', full_name='allego.NeuronDescriptor.meanAbsPeakWfm', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='snr', full_name='allego.NeuronDescriptor.snr', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metaData', full_name='allego.NeuronDescriptor.metaData', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3735,
  serialized_end=3978,
)


_NEURONEXTENDEDMETADATA = _descriptor.Descriptor(
  name='NeuronExtendedMetadata',
  full_name='allego.NeuronExtendedMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='neuronCatalogUID', full_name='allego.NeuronExtendedMetadata.neuronCatalogUID', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ensembleUID', full_name='allego.NeuronExtendedMetadata.ensembleUID', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='funcAssemblyUID', full_name='allego.NeuronExtendedMetadata.funcAssemblyUID', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='datasetUID', full_name='allego.NeuronExtendedMetadata.datasetUID', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='probeUID', full_name='allego.NeuronExtendedMetadata.probeUID', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3981,
  serialized_end=4115,
)


_NEURONSTATISTICS = _descriptor.Descriptor(
  name='NeuronStatistics',
  full_name='allego.NeuronStatistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='WaveformAvgAbsAmpl', full_name='allego.NeuronStatistics.WaveformAvgAbsAmpl', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Snr', full_name='allego.NeuronStatistics.Snr', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeCount', full_name='allego.NeuronStatistics.spikeCount', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='avgSpikeRate', full_name='allego.NeuronStatistics.avgSpikeRate', index=3,
      number=4, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isih', full_name='allego.NeuronStatistics.isih', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4118,
  serialized_end=4257,
)


_SPIKEDESCRIPTOR = _descriptor.Descriptor(
  name='SpikeDescriptor',
  full_name='allego.SpikeDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='allego.SpikeDescriptor.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.SpikeDescriptor.label', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveform', full_name='allego.SpikeDescriptor.waveform', index=2,
      number=3, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='allego.SpikeDescriptor.features', index=3,
      number=4, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='decFeatures', full_name='allego.SpikeDescriptor.decFeatures', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscore', full_name='allego.SpikeDescriptor.zscore', index=5,
      number=6, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4259,
  serialized_end=4383,
)


_SPIKEDATA = _descriptor.Descriptor(
  name='SpikeData',
  full_name='allego.SpikeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spike', full_name='allego.SpikeData.spike', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformMaxValue', full_name='allego.SpikeData.waveformMaxValue', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformMinValue', full_name='allego.SpikeData.waveformMinValue', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4385,
  serialized_end=4488,
)


_SPIKETIMEDATA = _descriptor.Descriptor(
  name='SpikeTimeData',
  full_name='allego.SpikeTimeData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='spikeTime', full_name='allego.SpikeTimeData.spikeTime', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.SpikeTimeData.label', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4490,
  serialized_end=4539,
)


_SPIKETIMESTAMPDATA = _descriptor.Descriptor(
  name='SpikeTimestampData',
  full_name='allego.SpikeTimestampData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeTimestampData.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimestamps', full_name='allego.SpikeTimestampData.spikeTimestamps', index=1,
      number=2, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='allego.SpikeTimestampData.labels', index=2,
      number=3, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4541,
  serialized_end=4622,
)


_SPIKETEMPLATEDESCRIPTOR = _descriptor.Descriptor(
  name='SpikeTemplateDescriptor',
  full_name='allego.SpikeTemplateDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='neuronID', full_name='allego.SpikeTemplateDescriptor.neuronID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.SpikeTemplateDescriptor.label', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.SpikeTemplateDescriptor.numSpikes', index=2,
      number=3, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveform', full_name='allego.SpikeTemplateDescriptor.waveform', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformSd', full_name='allego.SpikeTemplateDescriptor.waveformSd', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lenWaveform', full_name='allego.SpikeTemplateDescriptor.lenWaveform', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features', full_name='allego.SpikeTemplateDescriptor.features', index=6,
      number=7, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featuresSd', full_name='allego.SpikeTemplateDescriptor.featuresSd', index=7,
      number=8, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lenFeatures', full_name='allego.SpikeTemplateDescriptor.lenFeatures', index=8,
      number=9, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features2', full_name='allego.SpikeTemplateDescriptor.features2', index=9,
      number=10, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='features2Sd', full_name='allego.SpikeTemplateDescriptor.features2Sd', index=10,
      number=11, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lenFeatures2', full_name='allego.SpikeTemplateDescriptor.lenFeatures2', index=11,
      number=12, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscore', full_name='allego.SpikeTemplateDescriptor.zscore', index=12,
      number=13, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscoreSd', full_name='allego.SpikeTemplateDescriptor.zscoreSd', index=13,
      number=14, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lenZscore', full_name='allego.SpikeTemplateDescriptor.lenZscore', index=14,
      number=15, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4625,
  serialized_end=4935,
)


_SITESPIKETEMPLATES = _descriptor.Descriptor(
  name='SiteSpikeTemplates',
  full_name='allego.SiteSpikeTemplates',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SiteSpikeTemplates.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='template', full_name='allego.SiteSpikeTemplates.template', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4937,
  serialized_end=5028,
)


_BIOINTERFACESPIKETEMPLATESREPLY = _descriptor.Descriptor(
  name='BiointerfaceSpikeTemplatesReply',
  full_name='allego.BiointerfaceSpikeTemplatesReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceSpikeTemplatesReply.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.BiointerfaceSpikeTemplatesReply.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSpikeTemplatesReply.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceSpikeTemplatesReply.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.BiointerfaceSpikeTemplatesReply.site', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5031,
  serialized_end=5182,
)


_BIOINTERFACEMETADATA = _descriptor.Descriptor(
  name='BiointerfaceMetaData',
  full_name='allego.BiointerfaceMetaData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signalGroup', full_name='allego.BiointerfaceMetaData.signalGroup', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5184,
  serialized_end=5248,
)


_BIOINTERFACESPIKEDATAREPLY = _descriptor.Descriptor(
  name='BiointerfaceSpikeDataReply',
  full_name='allego.BiointerfaceSpikeDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='biointerfaceID', full_name='allego.BiointerfaceSpikeDataReply.biointerfaceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.BiointerfaceSpikeDataReply.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSpikeDataReply.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampRange', full_name='allego.BiointerfaceSpikeDataReply.timestampRange', index=3,
      number=4, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceSpikeDataReply.ntvChanIdx', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.BiointerfaceSpikeDataReply.site', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='metaData', full_name='allego.BiointerfaceSpikeDataReply.metaData', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5251,
  serialized_end=5465,
)


_SPIKEDATADENSECHANNELDESCRIPTOR = _descriptor.Descriptor(
  name='SpikeDataDenseChannelDescriptor',
  full_name='allego.SpikeDataDenseChannelDescriptor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SpikeDataDenseChannelDescriptor.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='labels', full_name='allego.SpikeDataDenseChannelDescriptor.labels', index=1,
      number=2, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformMaxValue', full_name='allego.SpikeDataDenseChannelDescriptor.waveformMaxValue', index=2,
      number=3, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformMinValue', full_name='allego.SpikeDataDenseChannelDescriptor.waveformMinValue', index=3,
      number=4, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5467,
  serialized_end=5588,
)


_BIOINTERFACESPIKEDATADENSEREPLY = _descriptor.Descriptor(
  name='BiointerfaceSpikeDataDenseReply',
  full_name='allego.BiointerfaceSpikeDataDenseReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSpikeDataDenseReply.timeRange', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformNPoints', full_name='allego.BiointerfaceSpikeDataDenseReply.waveformNPoints', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalNSpikes', full_name='allego.BiointerfaceSpikeDataDenseReply.totalNSpikes', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channelDescriptors', full_name='allego.BiointerfaceSpikeDataDenseReply.channelDescriptors', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='allego.BiointerfaceSpikeDataDenseReply.data', index=4,
      number=5, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5591,
  serialized_end=5773,
)


_GROUPSPIKETIMEDATAREPLY = _descriptor.Descriptor(
  name='GroupSpikeTimeDataReply',
  full_name='allego.GroupSpikeTimeDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.GroupSpikeTimeDataReply.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.GroupSpikeTimeDataReply.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.GroupSpikeTimeDataReply.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.GroupSpikeTimeDataReply.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.GroupSpikeTimeDataReply.site', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5776,
  serialized_end=5914,
)


_BIOINTERFACESPIKETRAIN = _descriptor.Descriptor(
  name='BiointerfaceSpiketrain',
  full_name='allego.BiointerfaceSpiketrain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceSpiketrain.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSpiketrain.timeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.BiointerfaceSpiketrain.sampFreq', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.BiointerfaceSpiketrain.site', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5916,
  serialized_end=6034,
)


_SITESPIKETRAIN = _descriptor.Descriptor(
  name='SiteSpiketrain',
  full_name='allego.SiteSpiketrain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.SiteSpiketrain.ntvChanIdx', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuron', full_name='allego.SiteSpiketrain.neuron', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.SiteSpiketrain.sampFreq', index=2,
      number=3, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeighbors', full_name='allego.SiteSpiketrain.numNeighbors', index=3,
      number=4, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6036,
  serialized_end=6148,
)


_SPIKETRAIN = _descriptor.Descriptor(
  name='Spiketrain',
  full_name='allego.Spiketrain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.Spiketrain.sampFreq', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='allego.Spiketrain.label', index=1,
      number=2, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeTimestamps', full_name='allego.Spiketrain.spikeTimestamps', index=2,
      number=3, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformData', full_name='allego.Spiketrain.waveformData', index=3,
      number=5, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='waveformShape', full_name='allego.Spiketrain.waveformShape', index=4,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featureData', full_name='allego.Spiketrain.featureData', index=5,
      number=7, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='featureShape', full_name='allego.Spiketrain.featureShape', index=6,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscoreData', full_name='allego.Spiketrain.zscoreData', index=7,
      number=9, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='zscoreShape', full_name='allego.Spiketrain.zscoreShape', index=8,
      number=10, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronDesc', full_name='allego.Spiketrain.neuronDesc', index=9,
      number=15, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numNeighbors', full_name='allego.Spiketrain.numNeighbors', index=10,
      number=17, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6151,
  serialized_end=6418,
)


_NEURONHISTDATA = _descriptor.Descriptor(
  name='NeuronHistData',
  full_name='allego.NeuronHistData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='binWidthSec', full_name='allego.NeuronHistData.binWidthSec', index=0,
      number=1, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='histTimeRange', full_name='allego.NeuronHistData.histTimeRange', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='allego.NeuronHistData.mode', index=2,
      number=3, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numRefEvents', full_name='allego.NeuronHistData.numRefEvents', index=3,
      number=4, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSpikes', full_name='allego.NeuronHistData.numSpikes', index=4,
      number=5, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numProcessedSpikes', full_name='allego.NeuronHistData.numProcessedSpikes', index=5,
      number=6, type=3, cpp_type=2, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hist', full_name='allego.NeuronHistData.hist', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6421,
  serialized_end=6603,
)


_SITEHISTDATA = _descriptor.Descriptor(
  name='SiteHistData',
  full_name='allego.SiteHistData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sitePosProbe', full_name='allego.SiteHistData.sitePosProbe', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sitePosBrain', full_name='allego.SiteHistData.sitePosBrain', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuron', full_name='allego.SiteHistData.neuron', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hist', full_name='allego.SiteHistData.hist', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.SiteHistData.timeRange', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6606,
  serialized_end=6763,
)


_BIOINTERFACEHISTDATAREPLY = _descriptor.Descriptor(
  name='BiointerfaceHistDataReply',
  full_name='allego.BiointerfaceHistDataReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceHistDataReply.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sampFreq', full_name='allego.BiointerfaceHistDataReply.sampFreq', index=1,
      number=2, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceHistDataReply.timeRange', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ntvChanIdx', full_name='allego.BiointerfaceHistDataReply.ntvChanIdx', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='site', full_name='allego.BiointerfaceHistDataReply.site', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6766,
  serialized_end=6905,
)


_BIOINTERFACESAVEREQUEST = _descriptor.Descriptor(
  name='BiointerfaceSaveRequest',
  full_name='allego.BiointerfaceSaveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceSaveRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.BiointerfaceSaveRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.BiointerfaceSaveRequest.baseName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeRange', full_name='allego.BiointerfaceSaveRequest.timeRange', index=3,
      number=4, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeComp', full_name='allego.BiointerfaceSaveRequest.spikeComp', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='includeNeuronTemplates', full_name='allego.BiointerfaceSaveRequest.includeNeuronTemplates', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6908,
  serialized_end=7088,
)


_BIOINTERFACELOADREQUEST = _descriptor.Descriptor(
  name='BiointerfaceLoadRequest',
  full_name='allego.BiointerfaceLoadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceLoadRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.BiointerfaceLoadRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.BiointerfaceLoadRequest.baseName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uidFragment', full_name='allego.BiointerfaceLoadRequest.uidFragment', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spikeComp', full_name='allego.BiointerfaceLoadRequest.spikeComp', index=4,
      number=5, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forceReplace', full_name='allego.BiointerfaceLoadRequest.forceReplace', index=5,
      number=6, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7091,
  serialized_end=7263,
)


_BIOINTERFACESAVELOADREPLY = _descriptor.Descriptor(
  name='BiointerfaceSaveLoadReply',
  full_name='allego.BiointerfaceSaveLoadReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceSaveLoadReply.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='allego.BiointerfaceSaveLoadReply.path', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='baseName', full_name='allego.BiointerfaceSaveLoadReply.baseName', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='allego.BiointerfaceSaveLoadReply.uid', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='biointerfaceMetaFile', full_name='allego.BiointerfaceSaveLoadReply.biointerfaceMetaFile', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='neuronTemplateFile', full_name='allego.BiointerfaceSaveLoadReply.neuronTemplateFile', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7266,
  serialized_end=7415,
)


_BIOINTERFACEGETIDSREPLY = _descriptor.Descriptor(
  name='BiointerfaceGetIDsReply',
  full_name='allego.BiointerfaceGetIDsReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='biointerfaceIDs', full_name='allego.BiointerfaceGetIDsReply.biointerfaceIDs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7417,
  serialized_end=7467,
)


_BIOINTERFACEVIZREQUEST = _descriptor.Descriptor(
  name='BiointerfaceVizRequest',
  full_name='allego.BiointerfaceVizRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dsourceID', full_name='allego.BiointerfaceVizRequest.dsourceID', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vizType', full_name='allego.BiointerfaceVizRequest.vizType', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numSamples', full_name='allego.BiointerfaceVizRequest.numSamples', index=2,
      number=3, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isYAutoScale', full_name='allego.BiointerfaceVizRequest.isYAutoScale', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='yLim', full_name='allego.BiointerfaceVizRequest.yLim', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='figDir', full_name='allego.BiointerfaceVizRequest.figDir', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isAutoOpen', full_name='allego.BiointerfaceVizRequest.isAutoOpen', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BIOINTERFACEVIZREQUEST_VTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7470,
  serialized_end=7709,
)


_BIOINTERFACEVIZREPLY = _descriptor.Descriptor(
  name='BiointerfaceVizReply',
  full_name='allego.BiointerfaceVizReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pngPathAndFileName', full_name='allego.BiointerfaceVizReply.pngPathAndFileName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7711,
  serialized_end=7761,
)

_SPIKESSPECREPLY.fields_by_name['site'].message_type = _SPIKESSITESPEC
_SPIKESSPECREPLY.fields_by_name['siteStats'].message_type = _SPIKESSITESTATS
_SPIKESSPECREPLY.fields_by_name['sensorExt'].message_type = common__pb2._SENSOREXTENDEDMETADATA
_SPIKESSPECREPLY.fields_by_name['project'].message_type = common__pb2._PROJECTMETADATA
_SPIKESSPECREPLY.fields_by_name['bioType'].enum_type = _BIOINTERFACETYPE
_SPIKESSITESPEC.fields_by_name['neighbor'].message_type = _NEIGHBORDESCRIPTOR
_SPIKESSITESPEC.fields_by_name['neuron'].message_type = _NEURONDESCRIPTOR
_SPIKESSITESPEC.fields_by_name['compLen'].message_type = _SPIKECOMPONENTLEN
_SPIKEMATRIXSET.fields_by_name['spkMtx'].message_type = _SPIKEMATRIX
_NEURONSPIKEMATRIXSET.fields_by_name['spkMtx'].message_type = _SPIKEMATRIX
_BIOINTERFACEGETSPIKESREQUEST.fields_by_name['mode'].enum_type = _NEURONSSIGNALMODE
_BIOINTERFACEGETSPIKESREQUEST.fields_by_name['spikeLabels'].message_type = _SPIKELABELRECORD
_BIOINTERFACEGETSPIKESREQUEST.fields_by_name['spikeComp'].enum_type = _SPIKEDESCRIPTORCOMPONENT
_BIOINTERFACEGETHISTREQUEST.fields_by_name['mode'].enum_type = _HISTSCALINGMODE
_BIOINTERFACEGETHISTREQUEST.fields_by_name['spikeLabels'].message_type = _SPIKELABELRECORD
_BIOINTERFACEGETSPIKETIMESTAMPSREQUEST.fields_by_name['spikeLabels'].message_type = _SPIKELABELRECORD
_BIOINTERFACESPIKETIMESTAMPSREPLY.fields_by_name['spikeTimestampsByChannel'].message_type = _SPIKETIMESTAMPDATA
_BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK.containing_type = _BIOINTERFACEGETNEURONSREPLY
_BIOINTERFACEGETNEURONSREPLY_NEURONL.fields_by_name['neuron'].message_type = _NEURONDESCRIPTOR
_BIOINTERFACEGETNEURONSREPLY_NEURONL.fields_by_name['chunk'].message_type = _BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK
_BIOINTERFACEGETNEURONSREPLY_NEURONL.containing_type = _BIOINTERFACEGETNEURONSREPLY
_BIOINTERFACEGETNEURONSREPLY_SITEENTRY.fields_by_name['value'].message_type = _BIOINTERFACEGETNEURONSREPLY_NEURONL
_BIOINTERFACEGETNEURONSREPLY_SITEENTRY.containing_type = _BIOINTERFACEGETNEURONSREPLY
_BIOINTERFACEGETNEURONSREPLY.fields_by_name['site'].message_type = _BIOINTERFACEGETNEURONSREPLY_SITEENTRY
_NEURONDESCRIPTOR.fields_by_name['metaData'].message_type = _NEURONEXTENDEDMETADATA
_NEURONSTATISTICS.fields_by_name['isih'].message_type = _NEURONHISTDATA
_SPIKEDATA.fields_by_name['spike'].message_type = _SPIKEDESCRIPTOR
_SITESPIKETEMPLATES.fields_by_name['template'].message_type = _SPIKETEMPLATEDESCRIPTOR
_BIOINTERFACESPIKETEMPLATESREPLY.fields_by_name['site'].message_type = _SITESPIKETEMPLATES
_BIOINTERFACEMETADATA.fields_by_name['signalGroup'].message_type = common__pb2._SIGNALGROUP
_BIOINTERFACESPIKEDATAREPLY.fields_by_name['site'].message_type = _SPIKEDATA
_BIOINTERFACESPIKEDATAREPLY.fields_by_name['metaData'].message_type = _BIOINTERFACEMETADATA
_BIOINTERFACESPIKEDATADENSEREPLY.fields_by_name['channelDescriptors'].message_type = _SPIKEDATADENSECHANNELDESCRIPTOR
_GROUPSPIKETIMEDATAREPLY.fields_by_name['site'].message_type = _SPIKETIMEDATA
_BIOINTERFACESPIKETRAIN.fields_by_name['site'].message_type = _SITESPIKETRAIN
_SITESPIKETRAIN.fields_by_name['neuron'].message_type = _SPIKETRAIN
_SPIKETRAIN.fields_by_name['neuronDesc'].message_type = _NEURONDESCRIPTOR
_NEURONHISTDATA.fields_by_name['mode'].enum_type = _HISTSCALINGMODE
_SITEHISTDATA.fields_by_name['neuron'].message_type = _NEURONDESCRIPTOR
_SITEHISTDATA.fields_by_name['hist'].message_type = _NEURONHISTDATA
_BIOINTERFACEHISTDATAREPLY.fields_by_name['site'].message_type = _SITEHISTDATA
_BIOINTERFACESAVEREQUEST.fields_by_name['spikeComp'].enum_type = _SPIKEDESCRIPTORCOMPONENT
_BIOINTERFACELOADREQUEST.fields_by_name['spikeComp'].enum_type = _SPIKEDESCRIPTORCOMPONENT
_BIOINTERFACEVIZREQUEST.fields_by_name['vizType'].enum_type = _BIOINTERFACEVIZREQUEST_VTYPE
_BIOINTERFACEVIZREQUEST_VTYPE.containing_type = _BIOINTERFACEVIZREQUEST
DESCRIPTOR.message_types_by_name['SpikesStdReq'] = _SPIKESSTDREQ
DESCRIPTOR.message_types_by_name['SpikesNewLoadReply'] = _SPIKESNEWLOADREPLY
DESCRIPTOR.message_types_by_name['SpikesRenameReq'] = _SPIKESRENAMEREQ
DESCRIPTOR.message_types_by_name['SpikesGetIDsReply'] = _SPIKESGETIDSREPLY
DESCRIPTOR.message_types_by_name['SpikesSpecReply'] = _SPIKESSPECREPLY
DESCRIPTOR.message_types_by_name['SpikesSiteSpec'] = _SPIKESSITESPEC
DESCRIPTOR.message_types_by_name['SpikeLabelRecord'] = _SPIKELABELRECORD
DESCRIPTOR.message_types_by_name['SpikeMatrix'] = _SPIKEMATRIX
DESCRIPTOR.message_types_by_name['SpikeMatrixSet'] = _SPIKEMATRIXSET
DESCRIPTOR.message_types_by_name['NeuronSpikeMatrixSet'] = _NEURONSPIKEMATRIXSET
DESCRIPTOR.message_types_by_name['BiointerfaceGetSpikesRequest'] = _BIOINTERFACEGETSPIKESREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceGetHistRequest'] = _BIOINTERFACEGETHISTREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceGetSpikeTimestampsRequest'] = _BIOINTERFACEGETSPIKETIMESTAMPSREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceSpikeTimestampsReply'] = _BIOINTERFACESPIKETIMESTAMPSREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceSeekEndSpikeTimestampsRequest'] = _BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceGetNeuronsRequest'] = _BIOINTERFACEGETNEURONSREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceGetNeuronsReply'] = _BIOINTERFACEGETNEURONSREPLY
DESCRIPTOR.message_types_by_name['SpikesSiteStats'] = _SPIKESSITESTATS
DESCRIPTOR.message_types_by_name['SpikeComponentLen'] = _SPIKECOMPONENTLEN
DESCRIPTOR.message_types_by_name['NeighborDescriptor'] = _NEIGHBORDESCRIPTOR
DESCRIPTOR.message_types_by_name['NeuronDescriptor'] = _NEURONDESCRIPTOR
DESCRIPTOR.message_types_by_name['NeuronExtendedMetadata'] = _NEURONEXTENDEDMETADATA
DESCRIPTOR.message_types_by_name['NeuronStatistics'] = _NEURONSTATISTICS
DESCRIPTOR.message_types_by_name['SpikeDescriptor'] = _SPIKEDESCRIPTOR
DESCRIPTOR.message_types_by_name['SpikeData'] = _SPIKEDATA
DESCRIPTOR.message_types_by_name['SpikeTimeData'] = _SPIKETIMEDATA
DESCRIPTOR.message_types_by_name['SpikeTimestampData'] = _SPIKETIMESTAMPDATA
DESCRIPTOR.message_types_by_name['SpikeTemplateDescriptor'] = _SPIKETEMPLATEDESCRIPTOR
DESCRIPTOR.message_types_by_name['SiteSpikeTemplates'] = _SITESPIKETEMPLATES
DESCRIPTOR.message_types_by_name['BiointerfaceSpikeTemplatesReply'] = _BIOINTERFACESPIKETEMPLATESREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceMetaData'] = _BIOINTERFACEMETADATA
DESCRIPTOR.message_types_by_name['BiointerfaceSpikeDataReply'] = _BIOINTERFACESPIKEDATAREPLY
DESCRIPTOR.message_types_by_name['SpikeDataDenseChannelDescriptor'] = _SPIKEDATADENSECHANNELDESCRIPTOR
DESCRIPTOR.message_types_by_name['BiointerfaceSpikeDataDenseReply'] = _BIOINTERFACESPIKEDATADENSEREPLY
DESCRIPTOR.message_types_by_name['GroupSpikeTimeDataReply'] = _GROUPSPIKETIMEDATAREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceSpiketrain'] = _BIOINTERFACESPIKETRAIN
DESCRIPTOR.message_types_by_name['SiteSpiketrain'] = _SITESPIKETRAIN
DESCRIPTOR.message_types_by_name['Spiketrain'] = _SPIKETRAIN
DESCRIPTOR.message_types_by_name['NeuronHistData'] = _NEURONHISTDATA
DESCRIPTOR.message_types_by_name['SiteHistData'] = _SITEHISTDATA
DESCRIPTOR.message_types_by_name['BiointerfaceHistDataReply'] = _BIOINTERFACEHISTDATAREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceSaveRequest'] = _BIOINTERFACESAVEREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceLoadRequest'] = _BIOINTERFACELOADREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceSaveLoadReply'] = _BIOINTERFACESAVELOADREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceGetIDsReply'] = _BIOINTERFACEGETIDSREPLY
DESCRIPTOR.message_types_by_name['BiointerfaceVizRequest'] = _BIOINTERFACEVIZREQUEST
DESCRIPTOR.message_types_by_name['BiointerfaceVizReply'] = _BIOINTERFACEVIZREPLY
DESCRIPTOR.enum_types_by_name['BiointerfaceType'] = _BIOINTERFACETYPE
DESCRIPTOR.enum_types_by_name['SpikesImportSchema'] = _SPIKESIMPORTSCHEMA
DESCRIPTOR.enum_types_by_name['BiointerfaceCommand'] = _BIOINTERFACECOMMAND
DESCRIPTOR.enum_types_by_name['BiointerfaceState'] = _BIOINTERFACESTATE
DESCRIPTOR.enum_types_by_name['NeuronsSignalMode'] = _NEURONSSIGNALMODE
DESCRIPTOR.enum_types_by_name['SpikeDescriptorComponent'] = _SPIKEDESCRIPTORCOMPONENT
DESCRIPTOR.enum_types_by_name['HistScalingMode'] = _HISTSCALINGMODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SpikesStdReq = _reflection.GeneratedProtocolMessageType('SpikesStdReq', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSTDREQ,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesStdReq)
  })
_sym_db.RegisterMessage(SpikesStdReq)

SpikesNewLoadReply = _reflection.GeneratedProtocolMessageType('SpikesNewLoadReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESNEWLOADREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesNewLoadReply)
  })
_sym_db.RegisterMessage(SpikesNewLoadReply)

SpikesRenameReq = _reflection.GeneratedProtocolMessageType('SpikesRenameReq', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESRENAMEREQ,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesRenameReq)
  })
_sym_db.RegisterMessage(SpikesRenameReq)

SpikesGetIDsReply = _reflection.GeneratedProtocolMessageType('SpikesGetIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESGETIDSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesGetIDsReply)
  })
_sym_db.RegisterMessage(SpikesGetIDsReply)

SpikesSpecReply = _reflection.GeneratedProtocolMessageType('SpikesSpecReply', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSPECREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSpecReply)
  })
_sym_db.RegisterMessage(SpikesSpecReply)

SpikesSiteSpec = _reflection.GeneratedProtocolMessageType('SpikesSiteSpec', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSITESPEC,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSiteSpec)
  })
_sym_db.RegisterMessage(SpikesSiteSpec)

SpikeLabelRecord = _reflection.GeneratedProtocolMessageType('SpikeLabelRecord', (_message.Message,), {
  'DESCRIPTOR' : _SPIKELABELRECORD,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeLabelRecord)
  })
_sym_db.RegisterMessage(SpikeLabelRecord)

SpikeMatrix = _reflection.GeneratedProtocolMessageType('SpikeMatrix', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEMATRIX,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeMatrix)
  })
_sym_db.RegisterMessage(SpikeMatrix)

SpikeMatrixSet = _reflection.GeneratedProtocolMessageType('SpikeMatrixSet', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEMATRIXSET,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeMatrixSet)
  })
_sym_db.RegisterMessage(SpikeMatrixSet)

NeuronSpikeMatrixSet = _reflection.GeneratedProtocolMessageType('NeuronSpikeMatrixSet', (_message.Message,), {
  'DESCRIPTOR' : _NEURONSPIKEMATRIXSET,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronSpikeMatrixSet)
  })
_sym_db.RegisterMessage(NeuronSpikeMatrixSet)

BiointerfaceGetSpikesRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetSpikesRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETSPIKESREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetSpikesRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetSpikesRequest)

BiointerfaceGetHistRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetHistRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETHISTREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetHistRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetHistRequest)

BiointerfaceGetSpikeTimestampsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetSpikeTimestampsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETSPIKETIMESTAMPSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetSpikeTimestampsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetSpikeTimestampsRequest)

BiointerfaceSpikeTimestampsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeTimestampsReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETIMESTAMPSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeTimestampsReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeTimestampsReply)

BiointerfaceSeekEndSpikeTimestampsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceSeekEndSpikeTimestampsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESEEKENDSPIKETIMESTAMPSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSeekEndSpikeTimestampsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceSeekEndSpikeTimestampsRequest)

BiointerfaceGetNeuronsRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceGetNeuronsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsRequest)
  })
_sym_db.RegisterMessage(BiointerfaceGetNeuronsRequest)

BiointerfaceGetNeuronsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceGetNeuronsReply', (_message.Message,), {

  'SpikeRateChunk' : _reflection.GeneratedProtocolMessageType('SpikeRateChunk', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_SPIKERATECHUNK,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.SpikeRateChunk)
    })
  ,

  'NeuronL' : _reflection.GeneratedProtocolMessageType('NeuronL', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_NEURONL,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.NeuronL)
    })
  ,

  'SiteEntry' : _reflection.GeneratedProtocolMessageType('SiteEntry', (_message.Message,), {
    'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY_SITEENTRY,
    '__module__' : 'biointerface_pb2'
    # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply.SiteEntry)
    })
  ,
  'DESCRIPTOR' : _BIOINTERFACEGETNEURONSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetNeuronsReply)
  })
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.SpikeRateChunk)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.NeuronL)
_sym_db.RegisterMessage(BiointerfaceGetNeuronsReply.SiteEntry)

SpikesSiteStats = _reflection.GeneratedProtocolMessageType('SpikesSiteStats', (_message.Message,), {
  'DESCRIPTOR' : _SPIKESSITESTATS,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikesSiteStats)
  })
_sym_db.RegisterMessage(SpikesSiteStats)

SpikeComponentLen = _reflection.GeneratedProtocolMessageType('SpikeComponentLen', (_message.Message,), {
  'DESCRIPTOR' : _SPIKECOMPONENTLEN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeComponentLen)
  })
_sym_db.RegisterMessage(SpikeComponentLen)

NeighborDescriptor = _reflection.GeneratedProtocolMessageType('NeighborDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _NEIGHBORDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeighborDescriptor)
  })
_sym_db.RegisterMessage(NeighborDescriptor)

NeuronDescriptor = _reflection.GeneratedProtocolMessageType('NeuronDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _NEURONDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronDescriptor)
  })
_sym_db.RegisterMessage(NeuronDescriptor)

NeuronExtendedMetadata = _reflection.GeneratedProtocolMessageType('NeuronExtendedMetadata', (_message.Message,), {
  'DESCRIPTOR' : _NEURONEXTENDEDMETADATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronExtendedMetadata)
  })
_sym_db.RegisterMessage(NeuronExtendedMetadata)

NeuronStatistics = _reflection.GeneratedProtocolMessageType('NeuronStatistics', (_message.Message,), {
  'DESCRIPTOR' : _NEURONSTATISTICS,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronStatistics)
  })
_sym_db.RegisterMessage(NeuronStatistics)

SpikeDescriptor = _reflection.GeneratedProtocolMessageType('SpikeDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeDescriptor)
  })
_sym_db.RegisterMessage(SpikeDescriptor)

SpikeData = _reflection.GeneratedProtocolMessageType('SpikeData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeData)
  })
_sym_db.RegisterMessage(SpikeData)

SpikeTimeData = _reflection.GeneratedProtocolMessageType('SpikeTimeData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETIMEDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTimeData)
  })
_sym_db.RegisterMessage(SpikeTimeData)

SpikeTimestampData = _reflection.GeneratedProtocolMessageType('SpikeTimestampData', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETIMESTAMPDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTimestampData)
  })
_sym_db.RegisterMessage(SpikeTimestampData)

SpikeTemplateDescriptor = _reflection.GeneratedProtocolMessageType('SpikeTemplateDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETEMPLATEDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeTemplateDescriptor)
  })
_sym_db.RegisterMessage(SpikeTemplateDescriptor)

SiteSpikeTemplates = _reflection.GeneratedProtocolMessageType('SiteSpikeTemplates', (_message.Message,), {
  'DESCRIPTOR' : _SITESPIKETEMPLATES,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteSpikeTemplates)
  })
_sym_db.RegisterMessage(SiteSpikeTemplates)

BiointerfaceSpikeTemplatesReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeTemplatesReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETEMPLATESREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeTemplatesReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeTemplatesReply)

BiointerfaceMetaData = _reflection.GeneratedProtocolMessageType('BiointerfaceMetaData', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEMETADATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceMetaData)
  })
_sym_db.RegisterMessage(BiointerfaceMetaData)

BiointerfaceSpikeDataReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeDataReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKEDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeDataReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeDataReply)

SpikeDataDenseChannelDescriptor = _reflection.GeneratedProtocolMessageType('SpikeDataDenseChannelDescriptor', (_message.Message,), {
  'DESCRIPTOR' : _SPIKEDATADENSECHANNELDESCRIPTOR,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SpikeDataDenseChannelDescriptor)
  })
_sym_db.RegisterMessage(SpikeDataDenseChannelDescriptor)

BiointerfaceSpikeDataDenseReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSpikeDataDenseReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKEDATADENSEREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpikeDataDenseReply)
  })
_sym_db.RegisterMessage(BiointerfaceSpikeDataDenseReply)

GroupSpikeTimeDataReply = _reflection.GeneratedProtocolMessageType('GroupSpikeTimeDataReply', (_message.Message,), {
  'DESCRIPTOR' : _GROUPSPIKETIMEDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.GroupSpikeTimeDataReply)
  })
_sym_db.RegisterMessage(GroupSpikeTimeDataReply)

BiointerfaceSpiketrain = _reflection.GeneratedProtocolMessageType('BiointerfaceSpiketrain', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSpiketrain)
  })
_sym_db.RegisterMessage(BiointerfaceSpiketrain)

SiteSpiketrain = _reflection.GeneratedProtocolMessageType('SiteSpiketrain', (_message.Message,), {
  'DESCRIPTOR' : _SITESPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteSpiketrain)
  })
_sym_db.RegisterMessage(SiteSpiketrain)

Spiketrain = _reflection.GeneratedProtocolMessageType('Spiketrain', (_message.Message,), {
  'DESCRIPTOR' : _SPIKETRAIN,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.Spiketrain)
  })
_sym_db.RegisterMessage(Spiketrain)

NeuronHistData = _reflection.GeneratedProtocolMessageType('NeuronHistData', (_message.Message,), {
  'DESCRIPTOR' : _NEURONHISTDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.NeuronHistData)
  })
_sym_db.RegisterMessage(NeuronHistData)

SiteHistData = _reflection.GeneratedProtocolMessageType('SiteHistData', (_message.Message,), {
  'DESCRIPTOR' : _SITEHISTDATA,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.SiteHistData)
  })
_sym_db.RegisterMessage(SiteHistData)

BiointerfaceHistDataReply = _reflection.GeneratedProtocolMessageType('BiointerfaceHistDataReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEHISTDATAREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceHistDataReply)
  })
_sym_db.RegisterMessage(BiointerfaceHistDataReply)

BiointerfaceSaveRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceSaveRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESAVEREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSaveRequest)
  })
_sym_db.RegisterMessage(BiointerfaceSaveRequest)

BiointerfaceLoadRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceLoadRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACELOADREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceLoadRequest)
  })
_sym_db.RegisterMessage(BiointerfaceLoadRequest)

BiointerfaceSaveLoadReply = _reflection.GeneratedProtocolMessageType('BiointerfaceSaveLoadReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACESAVELOADREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceSaveLoadReply)
  })
_sym_db.RegisterMessage(BiointerfaceSaveLoadReply)

BiointerfaceGetIDsReply = _reflection.GeneratedProtocolMessageType('BiointerfaceGetIDsReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEGETIDSREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceGetIDsReply)
  })
_sym_db.RegisterMessage(BiointerfaceGetIDsReply)

BiointerfaceVizRequest = _reflection.GeneratedProtocolMessageType('BiointerfaceVizRequest', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEVIZREQUEST,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceVizRequest)
  })
_sym_db.RegisterMessage(BiointerfaceVizRequest)

BiointerfaceVizReply = _reflection.GeneratedProtocolMessageType('BiointerfaceVizReply', (_message.Message,), {
  'DESCRIPTOR' : _BIOINTERFACEVIZREPLY,
  '__module__' : 'biointerface_pb2'
  # @@protoc_insertion_point(class_scope:allego.BiointerfaceVizReply)
  })
_sym_db.RegisterMessage(BiointerfaceVizReply)


DESCRIPTOR._options = None
_BIOINTERFACEGETNEURONSREPLY_SITEENTRY._options = None
# @@protoc_insertion_point(module_scope)
